# coding: utf-8

"""
    face_recognition

    face_recognition  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import edgegallery_face_recognition
from edgegallery_face_recognition.api.upload_api import UploadApi  # noqa: E501
from edgegallery_face_recognition.rest import ApiException


class TestUploadApi(unittest.TestCase):
    """UploadApi unit test stubs"""

    def setUp(self):
        self.api = UploadApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_upload_post(self):
        """Test case for upload_post

        upload images  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from edgegallery_sdk_face_recognition.api.default_api import DefaultApi
from edgegallery_sdk_face_recognition.api.recognition_api import RecognitionApi
from edgegallery_sdk_face_recognition.api.upload_api import UploadApi
from edgegallery_sdk_face_recognition.api.video_api import VideoApi


# coding: utf-8

"""
    face_recognition

    face_recognition  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import edgegallery_face_recognition
from edgegallery_face_recognition.models.body2 import Body2  # noqa: E501
from edgegallery_face_recognition.rest import ApiException


class TestBody2(unittest.TestCase):
    """Body2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBody2(self):
        """Test Body2"""
        # FIXME: construct object with mandatory attributes with example values
        # model = edgegallery_face_recognition.models.body2.Body2()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    face_recognition

    face_recognition  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# python 2 and python 3 compatibility library
import requests
import six



class VideoApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, url=None):
        if url is None:
            url = "face-recognition:9999/v1/face-recognition/recognition"
        self.url = url

    def add_url(self, body, **kwargs):  # noqa: E501
        """video face recognition  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        :param async_req bool
        :param Body body: video url (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        all_params = ['url']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'url' in params:
            local_var_files['url'] = params['url']  # noqa: E501
        print(local_var_files['url'])

        r = requests.post(self.url, files=local_var_files['url'])

        return r.text

    def add_url_with_http_info(self, body, **kwargs):  # noqa: E501
        """video face recognition  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_url_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Body body: video url (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['url']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'url' in params:
            local_var_files['url'] = params['url']  # noqa: E501
        print(local_var_files['url'])

        r = requests.post(self.url, url=local_var_files['url'])



# coding: utf-8

"""
    face_recognition

    face_recognition  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import
# python 2 and python 3 compatibility library
import requests



class DefaultApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, url=None):
        if url is None:
            url = "face-recognition:9999/v1/face-recognition"
        self.url = url

    def root_get(self):  # noqa: E501
        """helloworld  # noqa: E501

        test  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        r = requests.get(self.url)
        return r.headers

    def root_get_with_http_info(self):  # noqa: E501
        """helloworld  # noqa: E501

        test  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        r = requests.get(self.url)
        return r.text





# coding: utf-8

# flake8: noqa

"""
    face_recognition

    face_recognition  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from edgegallery_sdk_face_recognition.api.default_api import DefaultApi
from edgegallery_sdk_face_recognition.api.recognition_api import RecognitionApi
from edgegallery_sdk_face_recognition.api.upload_api import UploadApi
from edgegallery_sdk_face_recognition.api.video_api import VideoApi

